@@ -3,6 +3,7 @@ import os
 import sys
 import time
 import threading
+import traceback
 from argparse import ArgumentParser
 
 from ruamel.yaml.parser import ParserError
@@ -69,7 +70,10 @@ def validate_files(files):
             logger.error(str(e), source_id="YAML load")
             results.append(False)
         except Exception as e:
-            logger.error(str(e), source_id="YAML load")
+            print(repr(e))
+            _, __, exc_traceback = sys.exc_info()
+            tb = traceback.extract_tb(exc_traceback)
+            logger.error(f"{str(e)}: {''.join(tb.format())}", source_id="YAML load")
 
         loggers[file] = logger
 
