@@ -36,29 +36,39 @@ class Workflow:
         self.jobs = [Job(id, definition, context) for id, definition in definition.get("jobs", {}).items()]
 
     def __forms_dag(self, logger):
+        is_dag = False
         nodes = [ job.id for job in self.jobs ]
         edges = [(origin, target.id) for target in self.jobs if target.needs is not None for origin in target.needs ]
+        dag_source_id = f"{self.name} - DAG validator"
+        try:
+            G = nx.MultiDiGraph()
+            G.add_nodes_from(nodes)
+            G.add_edges_from(edges)
 
-        G = nx.MultiDiGraph()
-        G.add_nodes_from(nodes)
-        G.add_edges_from(edges)
-
-        is_dag = nx.algorithms.dag.is_directed_acyclic_graph(G)
-
-        if not is_dag:
-            logger.error("The workflow jobs do not form a directed acyclic graph", source_id=self.name)
+            is_dag = nx.algorithms.dag.is_directed_acyclic_graph(G)
 
+            if not is_dag:
+                logger.error("The workflow jobs do not form a directed acyclic graph",
+                             source_id=dag_source_id)
+        except TypeError as e:
+            logger.error(f"Caught an type error while validating the workflow's need structure: {e}",
+                         source_id=dag_source_id)
+        except Exception as e:
+            logger.error(f"Caught an unknown exception while validating the workflow's structure: {str(e)}",
+                         source_id=dag_source_id)
         return is_dag
 
     def __jobs_have_no_undefined_needs(self, logger):
         job_names = [job.id for job in self.jobs]
         jobs_with_needs = [job for job in self.jobs if job.needs is not None]
-
+        valid = True
         for job in jobs_with_needs:
             for need in job.needs:
                 if need not in job_names:
                     logger.error(f"Undefined need ({need}) in job {job.id}", source_id=job.id)
+                    valid = False
 
+        return valid
 
     def __validate_schema(self, logger):
         with open(os.path.join(os.path.dirname(os.path.realpath(__file__)), "..", "..", "utils", "schema.json")) as schema_file:
@@ -67,7 +77,8 @@ class Workflow:
         validator = Draft7Validator(__schema)
         valid = validator.is_valid(dict(self.raw_definition))
         for error in validator.iter_errors(dict(self.raw_definition)):
-            logger.error(f"{error.message} (path: {'.'.join(str(error.path))})", source_id=f"{self.name} - schema")
+            stringified_path_items = map(lambda x: str(x), error.path)
+            logger.error(f"{error.message} (path: {'.'.join(stringified_path_items)})", source_id=f"{self.name} - schema")
         return valid
 
     def __run_validator_and_log(self, validator, section_name, logger):
@@ -84,7 +95,6 @@ class Workflow:
         logger.info(f"\u2600 Workflow: {self.name}")
         section_logger = logger.new()
         schema_result = self.__run_validator_and_log(self.__validate_schema, "Schema validation", section_logger)
-
         dag_result = self.__run_validator_and_log(self.__forms_dag, "Check that jobs for a directed acyclic graph",
                                                   section_logger)
 
